# stbdl (Simple Taskbar Decoration Library)

Documentation: https://rncyk.org/docs/stbdl

Run the following command to install stbdl:

```
pip install stbdl
```
No dependencies need to be installed.

stbdl supports Python 3.x on Windows 10+
